==> zio-aws-honeycode_2.12-5.17.104.1-sources.jar: zio/aws/honeycode/model/CellInput.scala <==
package zio.aws.honeycode.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.honeycode.model.primitives.Fact
import scala.jdk.CollectionConverters._
final case class CellInput(fact: Option[Fact] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.honeycode.model.CellInput = {
    import CellInput.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.honeycode.model.CellInput
      .builder()
      .optionallyWith(fact.map(value => Fact.unwrap(value): java.lang.String))(
        _.fact
      )
      .build()
  }
  def asReadOnly: zio.aws.honeycode.model.CellInput.ReadOnly =
    zio.aws.honeycode.model.CellInput.wrap(buildAwsValue())
}
object CellInput {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.honeycode.model.CellInput
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.honeycode.model.CellInput =
      zio.aws.honeycode.model.CellInput(fact.map(value => value))
    def fact: Option[Fact]
    def getFact: ZIO[Any, AwsError, Fact] =
      AwsError.unwrapOptionField("fact", fact)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.honeycode.model.CellInput
  ) extends zio.aws.honeycode.model.CellInput.ReadOnly {
    override val fact: Option[Fact] = scala
      .Option(impl.fact())
      .map(value => zio.aws.honeycode.model.primitives.Fact(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.honeycode.model.CellInput
  ): zio.aws.honeycode.model.CellInput.ReadOnly = new Wrapper(impl)
}

==> zio-aws-honeycode_2.12-5.17.158.2-sources.jar: zio/aws/honeycode/model/CellInput.scala <==
package zio.aws.honeycode.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.honeycode.model.primitives.Fact
import scala.jdk.CollectionConverters._
final case class CellInput(
    fact: Option[Fact] = None,
    facts: Option[Iterable[Fact]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.honeycode.model.CellInput = {
    import CellInput.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.honeycode.model.CellInput
      .builder()
      .optionallyWith(fact.map(value => Fact.unwrap(value): java.lang.String))(
        _.fact
      )
      .optionallyWith(
        facts.map(value =>
          value.map { item =>
            Fact.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.facts)
      .build()
  }
  def asReadOnly: zio.aws.honeycode.model.CellInput.ReadOnly =
    zio.aws.honeycode.model.CellInput.wrap(buildAwsValue())
}
object CellInput {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.honeycode.model.CellInput
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.honeycode.model.CellInput = zio.aws.honeycode.model
      .CellInput(fact.map(value => value), facts.map(value => value))
    def fact: Option[Fact]
    def facts: Option[List[Fact]]
    def getFact: ZIO[Any, AwsError, Fact] =
      AwsError.unwrapOptionField("fact", fact)
    def getFacts: ZIO[Any, AwsError, List[Fact]] =
      AwsError.unwrapOptionField("facts", facts)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.honeycode.model.CellInput
  ) extends zio.aws.honeycode.model.CellInput.ReadOnly {
    override val fact: Option[Fact] = scala
      .Option(impl.fact())
      .map(value => zio.aws.honeycode.model.primitives.Fact(value))
    override val facts: Option[List[Fact]] = scala
      .Option(impl.facts())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.honeycode.model.primitives.Fact(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.honeycode.model.CellInput
  ): zio.aws.honeycode.model.CellInput.ReadOnly = new Wrapper(impl)
}
